import json


class Mock(object):

    data = None

    def to_string(self):
        if not isinstance(self.data,
                          (bytes, str, int, float, list, tuple, dict)):
            raise NotImplementedError(
                "to_string should be self defined for data type = {}".format(
                    type(self.data)))
        if isinstance(self.data, bytes):
            return str(self.data, encoding="utf8")
        if isinstance(self.data, (str, int, float)):
            return str(self.data)
        return json.dumps(self.data)




class WinneyRequestError(Exception):

    def __init__(self, message="failed to request data"):
        Exception.__init__(self, message)


class WinneyParamError(Exception):

    def __init__(self, message="invalid param"):
        Exception.__init__(self, message)


class NoServerAvalible(Exception):
    def __init__(self, message="cannot find an avalible server"):
        Exception.__init__(self, message)



#coding:utf-8

from os import path
from codecs import open
from setuptools import setup

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name="winney",
    version="0.5.4",
    author="olivetree",
    license="MIT",
    packages=["winney"],
    author_email="olivetree123@163.com",
    url="https://github.com/olivetree123/winney",
    description="Object-Oriented HTTP Request",
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=[
        "requests>=2.18.0",
    ],
)
